pub struct AgentSpecMemoryPolicyV1 {
pub enabled: bool,
pub mode: AgentMemoryModeV1,
pub requires_view_disclosure: bool,
}Fields
enabled: boolmode: AgentMemoryModeV1requires_view_disclosure: boolTrait Implementations
Sourceimpl Clone for AgentSpecMemoryPolicyV1
impl Clone for AgentSpecMemoryPolicyV1
Sourcefn clone(&self) -> AgentSpecMemoryPolicyV1
fn clone(&self) -> AgentSpecMemoryPolicyV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentSpecMemoryPolicyV1
impl Debug for AgentSpecMemoryPolicyV1
Sourceimpl<'de> Deserialize<'de> for AgentSpecMemoryPolicyV1
impl<'de> Deserialize<'de> for AgentSpecMemoryPolicyV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AgentSpecMemoryPolicyV1
Sourceimpl JsonSchema for AgentSpecMemoryPolicyV1
impl JsonSchema for AgentSpecMemoryPolicyV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentSpecMemoryPolicyV1
impl PartialEq for AgentSpecMemoryPolicyV1
Sourcefn eq(&self, other: &AgentSpecMemoryPolicyV1) -> bool
fn eq(&self, other: &AgentSpecMemoryPolicyV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentSpecMemoryPolicyV1
impl Serialize for AgentSpecMemoryPolicyV1
impl StructuralPartialEq for AgentSpecMemoryPolicyV1