pub struct AgentSpecProviderPolicyV1 {
pub provider: AgentProviderModeV1,
pub cloud_allowed: bool,
pub fallback_allowed: bool,
}Fields
provider: AgentProviderModeV1cloud_allowed: boolfallback_allowed: boolTrait Implementations
Sourceimpl Clone for AgentSpecProviderPolicyV1
impl Clone for AgentSpecProviderPolicyV1
Sourcefn clone(&self) -> AgentSpecProviderPolicyV1
fn clone(&self) -> AgentSpecProviderPolicyV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentSpecProviderPolicyV1
impl Debug for AgentSpecProviderPolicyV1
Sourceimpl<'de> Deserialize<'de> for AgentSpecProviderPolicyV1
impl<'de> Deserialize<'de> for AgentSpecProviderPolicyV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AgentSpecProviderPolicyV1
Sourceimpl JsonSchema for AgentSpecProviderPolicyV1
impl JsonSchema for AgentSpecProviderPolicyV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentSpecProviderPolicyV1
impl PartialEq for AgentSpecProviderPolicyV1
Sourcefn eq(&self, other: &AgentSpecProviderPolicyV1) -> bool
fn eq(&self, other: &AgentSpecProviderPolicyV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AgentSpecProviderPolicyV1