pub struct CapabilityGateDecisionDraftV1 {
pub tool_id: String,
pub outcome: CapabilityGateOutcomeV1,
pub lifecycle: Vec<ToolLifecycleStateV1>,
pub risk_class: CanonicalToolSideEffectClass,
pub permit_required: bool,
pub executable_this_turn: bool,
pub sandbox_root: Option<String>,
pub approval_request: Option<ApprovalRequestV1>,
pub permit_grant_id: Option<ArtifactId>,
pub permit_use_receipt_id: Option<ArtifactId>,
pub reason_codes: Vec<String>,
}Fields
tool_id: Stringoutcome: CapabilityGateOutcomeV1lifecycle: Vec<ToolLifecycleStateV1>risk_class: CanonicalToolSideEffectClasspermit_required: boolexecutable_this_turn: boolsandbox_root: Option<String>approval_request: Option<ApprovalRequestV1>permit_grant_id: Option<ArtifactId>permit_use_receipt_id: Option<ArtifactId>reason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for CapabilityGateDecisionDraftV1
impl Clone for CapabilityGateDecisionDraftV1
Sourcefn clone(&self) -> CapabilityGateDecisionDraftV1
fn clone(&self) -> CapabilityGateDecisionDraftV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CapabilityGateDecisionDraftV1
impl<'de> Deserialize<'de> for CapabilityGateDecisionDraftV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CapabilityGateDecisionDraftV1
Sourceimpl JsonSchema for CapabilityGateDecisionDraftV1
impl JsonSchema for CapabilityGateDecisionDraftV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CapabilityGateDecisionDraftV1
impl PartialEq for CapabilityGateDecisionDraftV1
Sourcefn eq(&self, other: &CapabilityGateDecisionDraftV1) -> bool
fn eq(&self, other: &CapabilityGateDecisionDraftV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CapabilityGateDecisionDraftV1