pub struct ConfigApplyReportDraftV1 {
pub app_id: String,
pub config_source: String,
pub provider_route: ProviderRouteReportV1,
pub tool_exposure: ToolExposureSetV1,
pub memory_mode: MemoryModeV1,
pub receipt_level: ReportLevelV1,
pub enabled_tool_bundles: Vec<String>,
pub sandbox_root: Option<String>,
pub applied: bool,
pub reason_codes: Vec<String>,
}Fields
app_id: Stringconfig_source: Stringprovider_route: ProviderRouteReportV1tool_exposure: ToolExposureSetV1memory_mode: MemoryModeV1receipt_level: ReportLevelV1enabled_tool_bundles: Vec<String>sandbox_root: Option<String>applied: boolreason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for ConfigApplyReportDraftV1
impl Clone for ConfigApplyReportDraftV1
Sourcefn clone(&self) -> ConfigApplyReportDraftV1
fn clone(&self) -> ConfigApplyReportDraftV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigApplyReportDraftV1
impl Debug for ConfigApplyReportDraftV1
Sourceimpl<'de> Deserialize<'de> for ConfigApplyReportDraftV1
impl<'de> Deserialize<'de> for ConfigApplyReportDraftV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigApplyReportDraftV1
Sourceimpl JsonSchema for ConfigApplyReportDraftV1
impl JsonSchema for ConfigApplyReportDraftV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigApplyReportDraftV1
impl PartialEq for ConfigApplyReportDraftV1
Sourcefn eq(&self, other: &ConfigApplyReportDraftV1) -> bool
fn eq(&self, other: &ConfigApplyReportDraftV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConfigApplyReportDraftV1
impl Serialize for ConfigApplyReportDraftV1
impl StructuralPartialEq for ConfigApplyReportDraftV1