pub struct DisplayDigestV1 {
pub algorithm: String,
pub canonicalization: String,
pub digest: String,
pub non_authoritative: bool,
pub reason_codes: Vec<String>,
}Fields
algorithm: Stringcanonicalization: Stringdigest: Stringreason_codes: Vec<String>Implementations
Sourceimpl DisplayDigestV1
impl DisplayDigestV1
pub fn for_json_value(value: &Value) -> Self
pub fn for_text(text: &str) -> Self
Sourcepub fn from_hex(hex_digest: impl Into<String>) -> Self
pub fn from_hex(hex_digest: impl Into<String>) -> Self
Construct a DisplayDigestV1 from a pre-computed hex digest string.
Use this when the digest has already been computed by a boundary compiler or other subsystem that produces SHA-256 hex strings.
pub fn from_stack_content_digest_for_display( digest: StackContentDigest, canonicalization: impl Into<String>, ) -> Self