pub struct ExecutionContextRefV1 {
pub execution_id: ArtifactId,
pub trace_id: ArtifactId,
pub operation_id: String,
}Fields
execution_id: ArtifactIdtrace_id: ArtifactIdoperation_id: StringTrait Implementations
Sourceimpl Clone for ExecutionContextRefV1
impl Clone for ExecutionContextRefV1
Sourcefn clone(&self) -> ExecutionContextRefV1
fn clone(&self) -> ExecutionContextRefV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionContextRefV1
impl Debug for ExecutionContextRefV1
Sourceimpl<'de> Deserialize<'de> for ExecutionContextRefV1
impl<'de> Deserialize<'de> for ExecutionContextRefV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionContextRefV1
Sourceimpl JsonSchema for ExecutionContextRefV1
impl JsonSchema for ExecutionContextRefV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionContextRefV1
impl PartialEq for ExecutionContextRefV1
Sourcefn eq(&self, other: &ExecutionContextRefV1) -> bool
fn eq(&self, other: &ExecutionContextRefV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionContextRefV1
impl Serialize for ExecutionContextRefV1
impl StructuralPartialEq for ExecutionContextRefV1