pub struct ExecutionLineageEdgeV1 {
pub parent_receipt_id: ArtifactId,
pub child_receipt_id: ArtifactId,
pub relation: String,
}Fields
parent_receipt_id: ArtifactIdchild_receipt_id: ArtifactIdrelation: StringTrait Implementations
Sourceimpl Clone for ExecutionLineageEdgeV1
impl Clone for ExecutionLineageEdgeV1
Sourcefn clone(&self) -> ExecutionLineageEdgeV1
fn clone(&self) -> ExecutionLineageEdgeV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionLineageEdgeV1
impl Debug for ExecutionLineageEdgeV1
Sourceimpl<'de> Deserialize<'de> for ExecutionLineageEdgeV1
impl<'de> Deserialize<'de> for ExecutionLineageEdgeV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionLineageEdgeV1
Sourceimpl JsonSchema for ExecutionLineageEdgeV1
impl JsonSchema for ExecutionLineageEdgeV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionLineageEdgeV1
impl PartialEq for ExecutionLineageEdgeV1
Sourcefn eq(&self, other: &ExecutionLineageEdgeV1) -> bool
fn eq(&self, other: &ExecutionLineageEdgeV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionLineageEdgeV1
impl Serialize for ExecutionLineageEdgeV1
impl StructuralPartialEq for ExecutionLineageEdgeV1