pub struct ExecutionLineageNodeV1 {
pub receipt_id: ArtifactId,
pub kind: ArtifactKindV1,
pub content_digest: String,
}Fields
receipt_id: ArtifactIdkind: ArtifactKindV1content_digest: StringTrait Implementations
Sourceimpl Clone for ExecutionLineageNodeV1
impl Clone for ExecutionLineageNodeV1
Sourcefn clone(&self) -> ExecutionLineageNodeV1
fn clone(&self) -> ExecutionLineageNodeV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionLineageNodeV1
impl Debug for ExecutionLineageNodeV1
Sourceimpl<'de> Deserialize<'de> for ExecutionLineageNodeV1
impl<'de> Deserialize<'de> for ExecutionLineageNodeV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionLineageNodeV1
Sourceimpl JsonSchema for ExecutionLineageNodeV1
impl JsonSchema for ExecutionLineageNodeV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionLineageNodeV1
impl PartialEq for ExecutionLineageNodeV1
Sourcefn eq(&self, other: &ExecutionLineageNodeV1) -> bool
fn eq(&self, other: &ExecutionLineageNodeV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionLineageNodeV1
impl Serialize for ExecutionLineageNodeV1
impl StructuralPartialEq for ExecutionLineageNodeV1