pub struct ProviderCertificationFixtureDraftV1 {
pub provider_kind: String,
pub scenario: String,
pub input_config: BTreeMap<String, String>,
pub expected_configured: bool,
pub expected_executable: bool,
pub expected_route_label: String,
pub expected_native_tool_loop: bool,
pub expected_reason_codes: Vec<String>,
}Fields
provider_kind: Stringscenario: Stringinput_config: BTreeMap<String, String>expected_configured: boolexpected_executable: boolexpected_route_label: Stringexpected_native_tool_loop: boolexpected_reason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for ProviderCertificationFixtureDraftV1
impl Clone for ProviderCertificationFixtureDraftV1
Sourcefn clone(&self) -> ProviderCertificationFixtureDraftV1
fn clone(&self) -> ProviderCertificationFixtureDraftV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProviderCertificationFixtureDraftV1
impl<'de> Deserialize<'de> for ProviderCertificationFixtureDraftV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderCertificationFixtureDraftV1
Sourceimpl JsonSchema for ProviderCertificationFixtureDraftV1
impl JsonSchema for ProviderCertificationFixtureDraftV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderCertificationFixtureDraftV1
impl PartialEq for ProviderCertificationFixtureDraftV1
Sourcefn eq(&self, other: &ProviderCertificationFixtureDraftV1) -> bool
fn eq(&self, other: &ProviderCertificationFixtureDraftV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProviderCertificationFixtureDraftV1