pub struct ProviderReadinessReportDraftV1 {
pub provider_kind: String,
pub model: Option<String>,
pub configured: bool,
pub executable: bool,
pub native_tool_loop_executable: bool,
pub route_label: String,
pub reason_codes: Vec<String>,
}Fields
provider_kind: Stringmodel: Option<String>configured: boolexecutable: boolnative_tool_loop_executable: boolroute_label: Stringreason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for ProviderReadinessReportDraftV1
impl Clone for ProviderReadinessReportDraftV1
Sourcefn clone(&self) -> ProviderReadinessReportDraftV1
fn clone(&self) -> ProviderReadinessReportDraftV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ProviderReadinessReportDraftV1
impl<'de> Deserialize<'de> for ProviderReadinessReportDraftV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderReadinessReportDraftV1
Sourceimpl JsonSchema for ProviderReadinessReportDraftV1
impl JsonSchema for ProviderReadinessReportDraftV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderReadinessReportDraftV1
impl PartialEq for ProviderReadinessReportDraftV1
Sourcefn eq(&self, other: &ProviderReadinessReportDraftV1) -> bool
fn eq(&self, other: &ProviderReadinessReportDraftV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProviderReadinessReportDraftV1