pub struct ProviderRouteReportDraftV2 {
pub provider_kind: String,
pub model: Option<String>,
pub route: ProviderRouteKindV1,
pub route_label: String,
pub chat_completion_executable: bool,
pub native_tool_loop: bool,
pub degraded: bool,
pub degraded_reason: Option<String>,
pub reason_codes: Vec<String>,
}Fields
provider_kind: Stringmodel: Option<String>route: ProviderRouteKindV1route_label: Stringchat_completion_executable: boolnative_tool_loop: booldegraded: booldegraded_reason: Option<String>reason_codes: Vec<String>Trait Implementations
Sourceimpl Clone for ProviderRouteReportDraftV2
impl Clone for ProviderRouteReportDraftV2
Sourcefn clone(&self) -> ProviderRouteReportDraftV2
fn clone(&self) -> ProviderRouteReportDraftV2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderRouteReportDraftV2
impl Debug for ProviderRouteReportDraftV2
Sourceimpl<'de> Deserialize<'de> for ProviderRouteReportDraftV2
impl<'de> Deserialize<'de> for ProviderRouteReportDraftV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderRouteReportDraftV2
Sourceimpl JsonSchema for ProviderRouteReportDraftV2
impl JsonSchema for ProviderRouteReportDraftV2
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderRouteReportDraftV2
impl PartialEq for ProviderRouteReportDraftV2
Sourcefn eq(&self, other: &ProviderRouteReportDraftV2) -> bool
fn eq(&self, other: &ProviderRouteReportDraftV2) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProviderRouteReportDraftV2