pub struct RuntimeCapabilityTruthV1 {
pub capability_id: String,
pub states: Vec<CapabilityStateV1>,
pub reason: Option<String>,
}Fields
capability_id: Stringstates: Vec<CapabilityStateV1>reason: Option<String>Trait Implementations
Sourceimpl Clone for RuntimeCapabilityTruthV1
impl Clone for RuntimeCapabilityTruthV1
Sourcefn clone(&self) -> RuntimeCapabilityTruthV1
fn clone(&self) -> RuntimeCapabilityTruthV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeCapabilityTruthV1
impl Debug for RuntimeCapabilityTruthV1
Sourceimpl<'de> Deserialize<'de> for RuntimeCapabilityTruthV1
impl<'de> Deserialize<'de> for RuntimeCapabilityTruthV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeCapabilityTruthV1
Sourceimpl JsonSchema for RuntimeCapabilityTruthV1
impl JsonSchema for RuntimeCapabilityTruthV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeCapabilityTruthV1
impl PartialEq for RuntimeCapabilityTruthV1
Sourcefn eq(&self, other: &RuntimeCapabilityTruthV1) -> bool
fn eq(&self, other: &RuntimeCapabilityTruthV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RuntimeCapabilityTruthV1
impl Serialize for RuntimeCapabilityTruthV1
impl StructuralPartialEq for RuntimeCapabilityTruthV1