pub struct SharedDispositionV1 {
pub schema_version: String,
pub shared_disposition_id: SharedDispositionId,
pub disposition_label: String,
pub treatment: String,
pub advisory_only: bool,
}Fields
schema_version: Stringdisposition_label: Stringtreatment: Stringadvisory_only: boolTrait Implementations
Sourcefn clone(&self) -> SharedDispositionV1
fn clone(&self) -> SharedDispositionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SharedDispositionV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SharedDispositionV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn eq(&self, other: &SharedDispositionV1) -> bool
fn eq(&self, other: &SharedDispositionV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more